import numpy as np

def write_file(t, a_file, drift_log_file, sync_param, time, fmt):
    write_acq_file(a_file, t, time, fmt)
    write_drift_log(drift_log_file, sync_param)
    

def write_acq_file(a_file, t, time, fmt):
	np.savetxt(a_file, t, fmt=fmt, delimiter='	', newline='\n', header='', footer='', comments ='')


def write_drift_log(filename, sync_param):

    sync_time = sync_param['sync_time']
    
    if not sync_param['mode']:
        filename.write('%s' % sync_time + '\n')
        sync_param['mode'] = 1
    else:
        filename.write('\n')
    
    print('%s' % '  ' + sync_time)


def write_annot_file(annot_file, annot):
    with open(annot_file, 'a') as file:
        file.write('{}	{}\n'.format(annot[0], annot[1]))
    
        


# local
from epibox.common.close_file import close_file 

def disconnect_system(devices, a_file=None, annot_file=None, drift_log_file=None, header=None, files_open=True): 

    for device in devices:
        try:
            device.stop()
            if header['service'] == 'Bitalino' or header['service'] == 'Mini':
                device.close()
        except:
            continue

    if files_open:
        close_file(a_file, annot_file, drift_log_file)





# third-party
from scipy import signal
import itertools
import numpy as np

def get_factors(n):
    n2 = n
    i = 2
    factors = []
    while i * i <= n:
        if n % i:
            i += 1
        else:
            n //= i
            factors.append(i)
    if n > 1:
        factors.append(n)
    
    factors.sort(reverse=True) 
    final_factors = [f for f in factors if f > 13]
    to_combine = [f for f in factors if f < 13]
    combos = list(itertools.combinations(to_combine, 2))

    while np.prod(final_factors) != n2:
        
        print('combos: {}'.format(combos))
        combination = [[i,p] for i,p in enumerate([x * y for x,y in combos]) if p <= 13]

        final_factors += [combination[0][1]]
        print('final_factors: {}'.format(final_factors))

        combos.remove(combos[combination[0][0]])
    
    return final_factors

def decimate(t, fs):
    # if phisiological signal downsample to 100Hz, if acc decimate 10Hz
    t_display = []

    for i in range(t.shape[1]):
        t_aux = t[:,i]
        for n in get_factors(fs / 100):
            t_aux = signal.decimate(t_aux, int(n))
        
        t_display += [t_aux.tolist()]


    return t_display


#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.md') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

with open('requirements.txt') as requirements_file:
    requirements = requirements_file.read().splitlines()


test_requirements = [ ]

setup(
    author="Ana Sofia Carmo",
    author_email='anascacais@gmail.com',
    python_requires='>=3.6',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="EpiBOX is a Raspberry Pi tool for easy signal acquisition.",
    entry_points={
        'console_scripts': [
            'epibox=epibox.cli:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description_content_type='text/markdown',
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords=['epibox', 'signal acquisition', 'Raspberry Pi'],
    name='epibox',
    packages=find_packages(include=['epibox', 'epibox.*']),
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/anascacais/epibox',
    download_url ='https://github.com/anascacais/epibox/archive/refs/tags/v0.1.0.tar.gz',
    version='0.1.0',
    zip_safe=False,
)



import os

def create_folder(initial_dir, nb, service):

    directory = os.path.join(initial_dir, nb)
    directory = os.path.join(directory, service)
    
    if not os.path.exists(directory):
        os.makedirs(directory)
        print('Created patient directory -- ' + directory)
            
    else:
        print('Directory -- {} -- already exists'.format(directory))

    return directory
